@@ -256,7 +256,7 @@ namespace osgEarth { namespace MVT
 
                     // Close the ring.
                     currentRing->close();
-
+                    
                     // New polygon
                     if (area > 0)
                     {
@@ -388,9 +388,12 @@ namespace osgEarth { namespace MVT
                         {
                             std::string other_tags = value.string_value();
 
-                            StringTokenizer tok("=>");
-                            StringVector tized;
-                            tok.tokenize(other_tags, tized);
+                            auto tized = StringTokenizer()
+                                .delim("=")
+                                .delim(">")
+                                .standardQuotes()
+                                .tokenize(other_tags);
+
                             if (tized.size() == 3)
                             {
                                 if (tized[0] == "height")
@@ -437,6 +440,7 @@ namespace osgEarth { namespace MVT
                     }
                     else
                     {
+                        OE_SOFT_ASSERT(false, "MVT: unsupported geometry type \"" << feature.type() << "\"");
                         geometry = decodeLine(feature, key, layer.extent());
                     }
 
